SignVariable

Struct SignVariable 

pub struct SignVariable {
    pub index: u8,
    pub source: u8,
    pub argument: i16,
}
64/6c Request/Command

  • byte index Destination and first operand variable index. 0..31.
  • byte source Source type for second operand. Only 0 and 2 allowed.
  • short argument Argument for second operand.

Set the value of variable index to 0 if the value specified by source and argument is equal to 0, 1 if the value specified by source and argument is positive, or -1 if the value specified by source and argument is negative.

93/9b Reply

  • void

Reply indicates success.

Fields

index: u8source: u8argument: i16